"""Generated catalog of Alignment Service v1 API endpoints."""

API_ENDPOINTS = [
    {"module": "alignments", "function": "delete_alignment", "method": "DELETE", "path": "/{alignment_id}"},
    {"module": "alignments", "function": "get_alignments", "method": "GET", "path": "/"},
    {"module": "alignments", "function": "get_alignment_by_name", "method": "GET", "path": "/name/{name}"},
    {"module": "alignments", "function": "get_alignments_by_type", "method": "GET", "path": "/type/{type_id}/alignments"},
    {"module": "alignments", "function": "get_alignment_types", "method": "GET", "path": "/types"},
    {"module": "alignments", "function": "get_alignment_type_by_name", "method": "GET", "path": "/types/name/{type_name}"},
    {"module": "alignments", "function": "get_alignment_type", "method": "GET", "path": "/types/{type_id}"},
    {"module": "alignments", "function": "get_alignment", "method": "GET", "path": "/{alignment_id}"},
    {"module": "alignments", "function": "get_alignment_buckets", "method": "GET", "path": "/{alignment_id}/buckets"},
    {"module": "alignments", "function": "get_alignment_buckets_list", "method": "GET", "path": "/{alignment_id}/buckets/list"},
    {"module": "alignments", "function": "get_alignment_events", "method": "GET", "path": "/{alignment_id}/events"},
    {"module": "alignments", "function": "get_alignment_findings", "method": "GET", "path": "/{alignment_id}/findings"},
    {"module": "alignments", "function": "get_alignment_findings_list", "method": "GET", "path": "/{alignment_id}/findings/list"},
    {"module": "alignments", "function": "update_alignment", "method": "PATCH", "path": "/{alignment_id}"},
    {"module": "alignments", "function": "create_alignment", "method": "POST", "path": "/"},
    {"module": "alignments", "function": "execute_alignment_bucket", "method": "POST", "path": "/{alignment_id}/buckets/{bucket_id}/execute"},
    {"module": "alignments", "function": "close_alignment", "method": "POST", "path": "/{alignment_id}/close"},
    {"module": "alignments", "function": "execute_alignment", "method": "POST", "path": "/{alignment_id}/execute"},
    {"module": "alignments", "function": "open_alignment", "method": "POST", "path": "/{alignment_id}/open"},
    {"module": "alignments", "function": "retry_failed_bucket_processing", "method": "POST", "path": "/{alignment_id}/retry-failed-buckets"},
    {"module": "bgtasks", "function": "monitor_task", "method": "GET", "path": "/{job_id}"},
    {"module": "buckets", "function": "delete_bucket", "method": "DELETE", "path": "/{bucket_id}"},
    {"module": "buckets", "function": "get_buckets_by_alignment", "method": "GET", "path": "/alignment/{alignment_id}"},
    {"module": "buckets", "function": "get_buckets_summary_by_alignment", "method": "GET", "path": "/alignment/{alignment_id}/summary"},
    {"module": "buckets", "function": "get_buckets_by_status", "method": "GET", "path": "/status/{status}"},
    {"module": "buckets", "function": "get_buckets_by_type", "method": "GET", "path": "/type/{bucket_type}"},
    {"module": "buckets", "function": "get_bucket", "method": "GET", "path": "/{bucket_id}"},
    {"module": "buckets", "function": "get_bucket_detail", "method": "GET", "path": "/{bucket_id}/detail"},
    {"module": "buckets", "function": "get_bucket_events", "method": "GET", "path": "/{bucket_id}/events"},
    {"module": "buckets", "function": "get_bucket_task_groups_summary", "method": "GET", "path": "/{bucket_id}/task-groups/summary"},
    {"module": "buckets", "function": "update_bucket_status", "method": "PATCH", "path": "/{bucket_id}/status"},
    {"module": "buckets", "function": "create_bucket", "method": "POST", "path": "/"},
    {"module": "commands", "function": "delete_command_group", "method": "DELETE", "path": "/groups/{group_id}"},
    {"module": "commands", "function": "remove_task_association_from_command_group", "method": "DELETE", "path": "/groups/{group_id}/task"},
    {"module": "commands", "function": "delete_command", "method": "DELETE", "path": "/{command_id}"},
    {"module": "commands", "function": "get_command_groups_by_bucket", "method": "GET", "path": "/groups/bucket/{bucket_id}"},
    {"module": "commands", "function": "get_command_groups_by_status", "method": "GET", "path": "/groups/status/{status}"},
    {"module": "commands", "function": "get_command_groups_by_task", "method": "GET", "path": "/groups/task/{task_id}"},
    {"module": "commands", "function": "get_command_group", "method": "GET", "path": "/groups/{group_id}"},
    {"module": "commands", "function": "get_commands_by_group", "method": "GET", "path": "/groups/{group_id}/commands"},
    {"module": "commands", "function": "get_command_group_events", "method": "GET", "path": "/groups/{group_id}/events"},
    {"module": "commands", "function": "get_mappings_by_command", "method": "GET", "path": "/mappings/command/{command_id}"},
    {"module": "commands", "function": "get_mappings_by_finding", "method": "GET", "path": "/mappings/finding/{finding_id}"},
    {"module": "commands", "function": "get_mappings_by_command_group", "method": "GET", "path": "/mappings/group/{group_id}"},
    {"module": "commands", "function": "get_command", "method": "GET", "path": "/{command_id}"},
    {"module": "commands", "function": "get_command_events", "method": "GET", "path": "/{command_id}/events"},
    {"module": "commands", "function": "get_items_created_before_command", "method": "GET", "path": "/{command_id}/items/created-before"},
    {"module": "commands", "function": "get_items_retired_before_command", "method": "GET", "path": "/{command_id}/items/retired-before"},
    {"module": "commands", "function": "get_items_updated_before_command", "method": "GET", "path": "/{command_id}/items/updated-before"},
    {"module": "commands", "function": "query_commands_referencing_command_item", "method": "GET", "path": "/{command_id}/referencing-commands"},
    {"module": "commands", "function": "update_command_group", "method": "PATCH", "path": "/groups/{group_id}"},
    {"module": "commands", "function": "update_command_group_status", "method": "PATCH", "path": "/groups/{group_id}/status"},
    {"module": "commands", "function": "update_command", "method": "PATCH", "path": "/{command_id}"},
    {"module": "commands", "function": "approve_command", "method": "PATCH", "path": "/{command_id}/approve"},
    {"module": "commands", "function": "mark_command_pending", "method": "PATCH", "path": "/{command_id}/pending"},
    {"module": "commands", "function": "reject_command", "method": "PATCH", "path": "/{command_id}/reject"},
    {"module": "commands", "function": "create_command_group", "method": "POST", "path": "/groups"},
    {"module": "commands", "function": "create_command", "method": "POST", "path": "/groups/{group_id}/commands"},
    {"module": "commands", "function": "push_command_group_to_task", "method": "POST", "path": "/groups/{group_id}/task"},
    {"module": "commands", "function": "query_commands_impacting_payload_before_command", "method": "POST", "path": "/impacting-commands"},
    {"module": "commands", "function": "query_display_options_from_items", "method": "POST", "path": "/items/display-options"},
    {"module": "commands", "function": "create_command_findings_mapping", "method": "POST", "path": "/mappings"},
    {"module": "commands", "function": "query_reference_options_before_command", "method": "POST", "path": "/{command_id}/items/reference-options"},
    {"module": "commands", "function": "update_command_findings_mappings", "method": "PUT", "path": "/mappings/command/{command_id}"},
    {"module": "findings", "function": "delete_finding", "method": "DELETE", "path": "/{finding_id}"},
    {"module": "findings", "function": "get_findings_by_alignment", "method": "GET", "path": "/alignment/{alignment_id}"},
    {"module": "findings", "function": "get_findings_by_bucket", "method": "GET", "path": "/bucket/{bucket_id}"},
    {"module": "findings", "function": "list_query_providers", "method": "GET", "path": "/match-queries/providers"},
    {"module": "findings", "function": "get_finding_match_query", "method": "GET", "path": "/match-queries/{match_query_id}"},
    {"module": "findings", "function": "get_finding", "method": "GET", "path": "/{finding_id}"},
    {"module": "findings", "function": "get_finding_events", "method": "GET", "path": "/{finding_id}/events"},
    {"module": "findings", "function": "get_finding_match_queries", "method": "GET", "path": "/{finding_id}/match-queries"},
    {"module": "findings", "function": "update_finding_match_query", "method": "PATCH", "path": "/match-queries/{match_query_id}"},
    {"module": "findings", "function": "update_finding_additional_data", "method": "PATCH", "path": "/{finding_id}/additional-data"},
    {"module": "findings", "function": "move_finding", "method": "PATCH", "path": "/{finding_id}/bucket"},
    {"module": "findings", "function": "create_add_finding", "method": "POST", "path": "/add"},
    {"module": "findings", "function": "create_add_finding_bulk", "method": "POST", "path": "/add/bulk"},
    {"module": "findings", "function": "create_retire_finding", "method": "POST", "path": "/retire"},
    {"module": "findings", "function": "create_retire_finding_list", "method": "POST", "path": "/retire/bulk"},
    {"module": "findings", "function": "create_update_finding", "method": "POST", "path": "/update"},
    {"module": "findings", "function": "create_update_finding_bulk", "method": "POST", "path": "/update/bulk"},
    {"module": "findings", "function": "create_finding_match_query", "method": "POST", "path": "/{finding_id}/match-queries"},
    {"module": "impact_assessments", "function": "get_alignment_dependency_graph", "method": "GET", "path": "/alignment/{alignment_id}/dependency-graph"},
    {"module": "impact_assessments", "function": "get_bucket_compiled_graph", "method": "GET", "path": "/bucket/{bucket_id}/compiled-graph"},
    {"module": "impact_assessments", "function": "get_bucket_dependency_graph", "method": "GET", "path": "/bucket/{bucket_id}/dependency-graph"},
    {"module": "impact_assessments", "function": "get_command_group_graph", "method": "GET", "path": "/command-group/{command_group_id}/command-graph"},
    {"module": "impact_assessments", "function": "get_command_graph", "method": "GET", "path": "/command/{command_id}/command-graph"},
    {"module": "impact_assessments", "function": "get_impact_assessment_by_finding", "method": "GET", "path": "/finding/{finding_id}"},
    {"module": "impact_assessments", "function": "get_finding_dependency_graph", "method": "GET", "path": "/finding/{finding_id}/dependency-graph"},
    {"module": "impact_assessments", "function": "get_finding_dependency_item_type_counts", "method": "GET", "path": "/finding/{finding_id}/dependency-graph/item-type-counts"},
    {"module": "impact_assessments", "function": "get_impact_assessment", "method": "GET", "path": "/{assessment_id}"},
    {"module": "impact_assessments", "function": "expand_alignment_dependency_graph", "method": "POST", "path": "/alignment/{alignment_id}/dependency-graph/expand"},
    {"module": "impact_assessments", "function": "get_bucket_dependency_graph_filtered", "method": "POST", "path": "/bucket/{bucket_id}/dependency-graph"},
    {"module": "impact_assessments", "function": "expand_bucket_dependency_graph", "method": "POST", "path": "/bucket/{bucket_id}/dependency-graph/expand"},
    {"module": "post_processing", "function": "drop_commands_alignment", "method": "DELETE", "path": "/alignments/{alignment_id}/drop-commands"},
    {"module": "post_processing", "function": "drop_commands_bucket", "method": "DELETE", "path": "/buckets/{bucket_id}/drop-commands"},
    {"module": "post_processing", "function": "download_alignment_artifacts_archive", "method": "GET", "path": "/alignments/{alignment_id}/artifacts-archive"},
    {"module": "post_processing", "function": "get_alignment_graph_status", "method": "GET", "path": "/alignments/{alignment_id}/graph/status"},
    {"module": "post_processing", "function": "download_alignment_validation_reports_archive", "method": "GET", "path": "/alignments/{alignment_id}/validation-reports-archive"},
    {"module": "post_processing", "function": "get_post_processing_job", "method": "GET", "path": "/jobs/{job_id}"},
    {"module": "post_processing", "function": "upload_alignment_source_file", "method": "POST", "path": "/alignments/source-file"},
    {"module": "post_processing", "function": "dryrun_commands_alignment", "method": "POST", "path": "/alignments/{alignment_id}/dryrun-commands"},
    {"module": "post_processing", "function": "generate_alignment_findings_summary_report", "method": "POST", "path": "/alignments/{alignment_id}/findings-summary-report"},
    {"module": "post_processing", "function": "register_alignment_graph_roots", "method": "POST", "path": "/alignments/{alignment_id}/graph/register-roots"},
    {"module": "post_processing", "function": "retry_failed_alignment_graph_work_items", "method": "POST", "path": "/alignments/{alignment_id}/graph/retry-failed"},
    {"module": "post_processing", "function": "start_alignment_graph_processing", "method": "POST", "path": "/alignments/{alignment_id}/graph/start-processing"},
    {"module": "post_processing", "function": "map_findings_alignment", "method": "POST", "path": "/alignments/{alignment_id}/map-findings"},
    {"module": "post_processing", "function": "dryrun_commands_bucket", "method": "POST", "path": "/buckets/{bucket_id}/dryrun-commands"},
    {"module": "post_processing", "function": "start_dryrun_commands_bucket_job", "method": "POST", "path": "/buckets/{bucket_id}/dryrun-commands/jobs"},
    {"module": "post_processing", "function": "map_findings_bucket", "method": "POST", "path": "/buckets/{bucket_id}/map-findings"},
    {"module": "post_processing", "function": "refresh_commands_generation_bucket", "method": "POST", "path": "/buckets/{bucket_id}/refresh-commands-generation"},
    {"module": "post_processing", "function": "run_command_generation_bucket", "method": "POST", "path": "/buckets/{bucket_id}/run-command-generation"},
    {"module": "registrations", "function": "delete_processor_registration", "method": "DELETE", "path": "/{registration_id}"},
    {"module": "registrations", "function": "list_processor_registrations", "method": "GET", "path": "/"},
    {"module": "registrations", "function": "get_processor_registration_by_type", "method": "GET", "path": "/by-type/{type_name}"},
    {"module": "registrations", "function": "get_processor_registration", "method": "GET", "path": "/{registration_id}"},
    {"module": "registrations", "function": "update_processor_registration", "method": "PATCH", "path": "/{registration_id}"},
    {"module": "registrations", "function": "upsert_processor_registration", "method": "POST", "path": "/"},
]

__all__ = ["API_ENDPOINTS"]
