from app.core.config import CeleryConfig


def test_celery_config_graph_burst_defaults() -> None:
    cfg = CeleryConfig()

    assert cfg.alignment_graph_enqueue_fetch_limit == 2000
    assert cfg.alignment_graph_processing_max_parallel_tasks == 8
    assert cfg.alignment_graph_retry_base_delay_seconds == 10
    assert cfg.alignment_graph_retry_max_attempts == 5
